@@ -45,8 +45,6 @@ XML::Filter::XML_Directory_2XHTML - SAX2 filter for munging XML::Directory::SAX
  my $writer = XML::SAX::Writer->new(Output=>$file);
  my $filter = XML::Filter::XML_Directory_2XHTML->new(Handler=>$writer);
 
- $filter->set_encoding("ISO-8858-1");
-
  # As Canadian as possible, under the circumstances
  $filter->set_lang("en-ca");
 
@@ -107,9 +105,9 @@ use Carp;
 use Exporter;
 use File::Basename;
 
-use XML::Filter::XML_Directory_2::Base '1.4.4';
+use XML::Filter::XML_Directory_2::Base '1.2';
 
-$XML::Filter::XML_Directory_2XHTML::VERSION   = '1.3.1';
+$XML::Filter::XML_Directory_2XHTML::VERSION   = '1.1';
 @XML::Filter::XML_Directory_2XHTML::ISA       = qw (Exporter XML::Filter::XML_Directory_2::Base);
 @XML::Filter::XML_Directory_2XHTML::EXPORT    = qw();
 @XML::Filter::XML_Directory_2XHTML::EXPORT_OK = qw ();
@@ -210,18 +208,7 @@ The default CSS styles for those classes are :
         margin-bottom:10px;
         }
 
- .thumbnail { display: inline; }
-
-They can be altered by passing a user-defined CSS stylesheet via the filter's I<set_styles> object method. You may also use the I<set_style> method to override the default and assign styles via the HTML <style> element.
-
-Example HTML output:
-
- <div class = "(file|directory)" id = "...">
-  <div class = "thumbnail">
-   <img src = "..." />
-  </div>
-  <a href = "...">Hello World picture</a>
- </div>
+They can be altered by passing a user-defined CSS stylesheet via the filter's I<set_styles> object method.
 
 =head1 OBJECT METHODS
 
@@ -264,7 +251,7 @@ I<string> - the value returned by the I<MIME::Types::mediaType> function for a d
 
 =back
 
-Each key defines a value which is also a hash reference whose keys are :
+Each key defines it own hash reference whose keys are :
 
 =over
 
@@ -294,10 +281,6 @@ String.
 
 =back
 
-Alternately, you may pass a code reference as the key value. If you do, your code reference wil be passed the absolute path of the current file as the first, and only, argument.
-
-Your code reference should return a hash reference whose key/value pairs are the same as those outlined above.
-
 =cut
 
 sub set_images {
@@ -310,15 +293,8 @@ sub set_images {
   }
 
   foreach my $img (keys %$args) {
-    my $ref = ref($args->{$img});
-
-    unless ($ref =~ /^(HASH|CODE)$/) {
-      carp "Images must be passed as a hash ref of hash references or code references.";
-      next;
-    }
-
-    if ($ref eq "CODE") {
-      $self->{'__images'}{$img} = $args->{$img};
+    if (ref($args->{$img}) ne "HASH") {
+      carp "Images must be passed as a hash ref of hash references.";
       next;
     }
 
@@ -395,21 +371,6 @@ sub set_styles {
   return 1;
 }
 
-=head2 $pkg->set_style(\$css)
-
-You may use this method to override the default styles altogether without also assigning remote stylesheets.
-
- $pkg->set_style(\qq(.file{ border:2px dotted pink};));
-
-=cut
-
-sub set_style {
-  my $self = shift;
-  if (ref($_[0]) eq "SCALAR") {
-    $self->{__PACKAGE__.'__css'} = $_[0];
-  }
-}
-
 =head2 $pkg->set_scripts(\@scripts)
 
 Define scripts for your document.
@@ -476,12 +437,7 @@ sub _stylesheets {
 					   },
 			      });
 
-  if ($self->{__PACKAGE__.'__css'}) {
-    $self->comment({Data=>${$self->{__PACKAGE__.'__css'}}});
-  }
-
-  else {
-    $self->comment({Data=>qq(
+  $self->comment({Data=>qq(
 .file { 
          border:1px dotted #ccc;
          margin-left:10px;
@@ -494,10 +450,7 @@ sub _stylesheets {
         margin-left:10px;
         margin-bottom:10px;
         }
- .thumbnail { display:inline; }
-
 )});
-  }
 
   $self->SUPER::end_element({Name=>"style"});
 
@@ -537,7 +490,7 @@ sub _stylesheets {
 							  }});
     $self->SUPER::end_element({Name=>"link"});
   }
-
+ 
   return 1;
 }
 
@@ -567,7 +520,7 @@ sub _scripts {
 sub _image {
   my $self = shift;
   my $type = shift;
-  my $data = shift;
+  my $alt  = shift;
 
   if (! $type) {
     return 0;
@@ -579,18 +532,6 @@ sub _image {
     return 0;
   }
 
-  if (ref($src) eq "CODE") {
-    $src = &$src($self->build_uri($data)."/".&basename($self->current_location()));
-
-    if (ref($src) ne "HASH") { return 0; }
-
-    foreach ("src","height","width") {
-      if (! $src->{$_}) { return 0; }
-    }
-
-  }
-
-  $self->SUPER::start_element({Name=>"div",__PACKAGE__->attributes(class=>"thumbnail")});
   $self->SUPER::start_element({Name=>"img",Attributes=>{
 							"{}src"  => {Name=>"src",
 								     Value=>$src->{'src'},
@@ -614,7 +555,6 @@ sub _image {
 								       NameSpaceURI=>""},
 						       }});
   $self->SUPER::end_element({Name=>"img"});
-  $self->SUPER::end_element({Name=>"div"});
   return 1;
 }
 
@@ -629,11 +569,11 @@ sub _link {
 
   #
 
-  if (my $h = $self->retrieve_handler("linktext")) {
+  if (my $h = $self->get_handler("linktext")) {
     $self->SUPER::characters({Data=>$h->parse_uri($self->build_uri($data))});
   }
   
-  elsif (my $c = $self->retrieve_callback("linktext")) {
+  elsif (my $c = $self->get_callback("linktext")) {
     $self->SUPER::characters({Data=>&$c(
 					$self->build_uri($data),
 					$data->{Attributes}->{'{}name'}->{Value}
@@ -664,12 +604,10 @@ sub start_document {
   my $self = shift;
   $self->SUPER::start_document();
 
-  $self->SUPER::xml_decl({Version  => "1.0",
-			  Encoding => $self->encoding()});
-
-  $self->SUPER::start_dtd({Name     => DTD_HTML_ROOT,
-			   PublicId => DTD_HTML_PUBLICID,
-			   SystemId => DTD_HTML_SYSTEMID});
+  $self->SUPER::xml_decl({Version=>"1.0"});
+  $self->SUPER::start_dtd({Name=>DTD_HTML_ROOT,
+			   PublicId=>DTD_HTML_PUBLICID,
+			   SystemId=>DTD_HTML_SYSTEMID});
   $self->SUPER::end_dtd();
 
   $self->SUPER::start_prefix_mapping({Prefix => "",
@@ -710,9 +648,7 @@ sub start_element {
   my $self = shift;
   my $data = shift;
 
-  if (! $self->on_enter_start_element($data)) {
-    return 0;
-  }
+  $self->on_enter_start_element($data) || return 0;
 
   if ($data->{Name} =~ /^(file|directory)$/) {
     my $name = lc $1;
@@ -728,11 +664,11 @@ sub start_element {
     $self->_image($type);
     $self->_link($data);
 
-    if (my $h = $self->retrieve_handler($name)) {
+    if (my $h = $self->get_handler($name)) {
       $h->parse_uri($self->build_uri($data));
     }
 
-    elsif (my $c = $self->retrieve_callback($name)) {
+    elsif (my $c = $self->get_callback($name)) {
       $self->SUPER::characters({Data=>&$c($self->build_uri($data))});
     }
 
@@ -756,7 +692,7 @@ sub end_element {
 
     my $title = $self->current_location() || &basename($self->build_uri($data));
 
-    if (my $c = $self->retrieve_callback("title")) {
+    if (my $c = $self->get_callback("title")) {
       $title = &$c();
     }
 
@@ -802,11 +738,11 @@ sub characters {
 
 =head1 VERSION
 
-1.3.1
+1.1
 
 =head1 DATE
 
-July 22, 2002
+July 03, 2002
 
 =head1 AUTHOR
 
